==> nanoblogger-2.4.tar.gz: nanoblogger/plugins/list_entries.sh <==
# NanoBlogger List Entries Plugin
# make a list of N Recent entries and N Older entries
#
# sample code for templates, based off the default stylesheet
#
# <div class="sidetitle">	# <div> class="sidetitle">
# Recent Entries		# Older Entries
# </div>			# </div>
# <div class="side">		# <div class="side">
# $NB_Recent_Entries		# $NB_Older_Entries
# </div>			# </div>

# clear these, just to be safe
BEGIN_ENTRY=;END_ENTRY=;

# set entry number to begin at
BEGIN_ENTRY="1"
# set entry number to end at
END_ENTRY="10"

OUTPUT_FILE1="$BLOG_DIR/$PARTS_DIR/recent_entries.htm"
OUTPUT_FILE2="$BLOG_DIR/$PARTS_DIR/older_entries.htm"

html_bullet="&#8226;"

list_older(){
# set limit based on MAX_DISPLAY in user's blog.conf
BEGIN_ENTRY=`expr "$MAX_DISPLAY" + 1`
END_ENTRY=`expr "$MAX_DISPLAY" + "$MAX_DISPLAY"`
}

get_entries(){
local FILE="$1"
ENTRIES_LIST=`cd "$BLOG_DIR"/"$ARCHIVES" ; for files in *.* ; do echo "$files" ; done |sort -r`
LIST_OF_ENTRIES=`echo "$ENTRIES_LIST" |sed -n "$BEGIN_ENTRY","$END_ENTRY"p`
echo "" > "$FILE"
for entry in $LIST_OF_ENTRIES ; do
	title_link=`sed -n 1p "$BLOG_DIR/$ARCHIVES/$entry"`
	if [ "$FULL_PERMALINKS" = "1" ] ; then
		permalink="$BLOG_URL_ACTION""$PERMALINKS/$entry"
	else
		month_link=`echo "$entry" |cut -c1-7`
		permalink="$BLOG_URL/$ARCHIVES/$FILE_BY_DIR/$month_link.html#$entry"
	fi
	if [ -z "$title_link" ] ; then title_link="Untitled" ; fi
	cat >> "$FILE" <<-EOF 
		$html_bullet <a href="$permalink">$title_link</a><br />
	EOF
done
}

for list_mode in recent older; do
	if [ "$list_mode" = "older" ] ; then
		list_older ; get_entries "$OUTPUT_FILE2"
	else
		get_entries "$OUTPUT_FILE1"
	fi
done

NB_Recent_Entries=`cat "$OUTPUT_FILE1"`
NB_Older_Entries=`cat "$OUTPUT_FILE2"`

==> nanoblogger-2.5.tar.gz: nanoblogger/plugins/list_entries.sh <==
# NanoBlogger List Entries Plugin
# make a list of N Recent entries and N Older entries
#
# sample code for templates, based off the default stylesheet
#
# <div class="sidetitle">	# <div> class="sidetitle">
# Recent Entries		# Older Entries
# </div>			# </div>
# <div class="side">		# <div class="side">
# $NB_Recent_Entries		# $NB_Older_Entries
# </div>			# </div>

# clear these, just to be safe
BEGIN_ENTRY=;END_ENTRY=;

# set entry number to begin at
BEGIN_ENTRY="1"
# set entry number to end at
END_ENTRY="$MAX_DISPLAY"

OUTPUT_FILE1="$BLOG_DIR/$PARTS_DIR/recent_entries.htm"
OUTPUT_FILE2="$BLOG_DIR/$PARTS_DIR/older_entries.htm"

html_bullet="&#8226;"

list_older(){
# set limit based on MAX_DISPLAY in user's blog.conf
BEGIN_ENTRY=`expr "$MAX_DISPLAY" + 1`
END_ENTRY=`expr "$MAX_DISPLAY" + "$MAX_DISPLAY"`
}

get_entries(){
local FILE="$1"
ENTRIES_LIST=`cd "$BLOG_DIR"/"$ARCHIVES" ; for files in *.htm ; do echo "$files" ; done |sort -r`
LIST_OF_ENTRIES=`echo "$ENTRIES_LIST" |sed -n "$BEGIN_ENTRY","$END_ENTRY"p`
echo "" > "$FILE"
for entry in $LIST_OF_ENTRIES ; do
	title_link=`sed -n 1p "$BLOG_DIR/$ARCHIVES/$entry"`
	if [ "$FULL_PERMALINKS" = "1" ] ; then
		permalink="$BLOG_URL_ACTION""$PERMALINKS/$entry"
	else
		month_link=`echo "$entry" |cut -c1-7`
		permalink="$BLOG_URL/$ARCHIVES/$FILE_BY_DIR/$month_link.html#$entry"
	fi
	if [ -z "$title_link" ] ; then title_link="Untitled" ; fi
	cat >> "$FILE" <<-EOF 
		$html_bullet <a href="$permalink">$title_link</a><br />
	EOF
done
}

for list_mode in recent older; do
	if [ "$list_mode" = "older" ] ; then
		list_older ; get_entries "$OUTPUT_FILE2"
	else
		get_entries "$OUTPUT_FILE1"
	fi
done

NB_Recent_Entries=`cat "$OUTPUT_FILE1"`
NB_Older_Entries=`cat "$OUTPUT_FILE2"`
